@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Microsoft SQLServer hook module"""
+"""Microsoft SQLServer hook module."""
 from __future__ import annotations
 
 from typing import Any
@@ -28,12 +28,12 @@ from airflow.providers.common.sql.hooks.sql import DbApiHook
 class MsSqlHook(DbApiHook):
     """Interact with Microsoft SQL Server."""
 
-    conn_name_attr = 'mssql_conn_id'
-    default_conn_name = 'mssql_default'
-    conn_type = 'mssql'
-    hook_name = 'Microsoft SQL Server'
+    conn_name_attr = "mssql_conn_id"
+    default_conn_name = "mssql_default"
+    conn_type = "mssql"
+    hook_name = "Microsoft SQL Server"
     supports_autocommit = True
-    DEFAULT_SQLALCHEMY_SCHEME = 'mssql+pymssql'
+    DEFAULT_SQLALCHEMY_SCHEME = "mssql+pymssql"
 
     def __init__(
         self,
@@ -63,11 +63,10 @@ class MsSqlHook(DbApiHook):
     @property
     def sqlalchemy_scheme(self) -> str:
         """Sqlalchemy scheme either from constructor, connection extras or default."""
-        return (
-            self._sqlalchemy_scheme
-            or self.connection_extra_lower.get('sqlalchemy_scheme')
-            or self.DEFAULT_SQLALCHEMY_SCHEME
-        )
+        extra_scheme = self.connection_extra_lower.get("sqlalchemy_scheme")
+        if not self._sqlalchemy_scheme and extra_scheme and (":" in extra_scheme or "/" in extra_scheme):
+            raise RuntimeError("sqlalchemy_scheme in connection extra should not contain : or / characters")
+        return self._sqlalchemy_scheme or extra_scheme or self.DEFAULT_SQLALCHEMY_SCHEME
 
     def get_uri(self) -> str:
         from urllib.parse import parse_qs, urlencode, urlsplit, urlunsplit
@@ -78,7 +77,7 @@ class MsSqlHook(DbApiHook):
         # remove query string 'sqlalchemy_scheme' like parameters:
         qs = parse_qs(r[3], keep_blank_values=True)
         for k in list(qs.keys()):
-            if k.lower() == 'sqlalchemy_scheme':
+            if k.lower() == "sqlalchemy_scheme":
                 qs.pop(k, None)
         r[3] = urlencode(qs, doseq=True)
         return urlunsplit(r)
@@ -86,14 +85,12 @@ class MsSqlHook(DbApiHook):
     def get_sqlalchemy_connection(
         self, connect_kwargs: dict | None = None, engine_kwargs: dict | None = None
     ) -> Any:
-        """Sqlalchemy connection object"""
+        """Sqlalchemy connection object."""
         engine = self.get_sqlalchemy_engine(engine_kwargs=engine_kwargs)
         return engine.connect(**(connect_kwargs or {}))
 
-    def get_conn(
-        self,
-    ) -> pymssql.connect:
-        """Returns a mssql connection object"""
+    def get_conn(self) -> pymssql.connect:
+        """Returns a mssql connection object."""
         conn = self.get_connection(self.mssql_conn_id)  # type: ignore[attr-defined]
 
         conn = pymssql.connect(
